searchData={"content_type":"text/markdown","items":[{"doc":"Toggle is a stupid-simple feature flag library for Elixir.\n\nIt provides a simple API for enabling and disabling feature flags in your application.","ref":"Toggle.html","title":"Toggle","type":"module"},{"doc":"Add `toggle` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:toggle, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"Toggle.html#module-installation","title":"Installation - Toggle","type":"module"},{"doc":"In order to use Toggle, you need to add an Ecto Migration to your application to set up the database table\n`Toggle` will use to store data.\n\nCurrently, `Toggle` supports SQLite3 and Postgres as database backends.\n\nYou can create migrations using the `Toggle.Migrations.SQLite` or `Toggle.Migrations.Postgres` helper modules:\n\n```elixir\ndefmodule MyApp.Repo.Migrations.CreateFlagsTables do\n  use Ecto.Migration\n\n  def up do\n    # Replace `Toggle.Migrations.SQLite` with `Toggle.Migrations.Postgres` if you are using Postgres\n    Toggle.Migrations.SQLite.up(table: \"toggle_flags\")\n  end\n\n  def down do\n    # Replace `Toggle.Migrations.SQLite` with `Toggle.Migrations.Postgres` if you are using Postgres\n    Toggle.Migrations.SQLite.down(table: \"toggle_flags\")\n  end\nend\n```\n\nAfter you have run your migrations, you can start using `Toggle` in your application.\n\n```elixir\niex> Toggle.enabled?(\"my_feature\")\nfalse\niex> Toggle.enable!(\"my_feature\")\n:ok\niex> Toggle.enabled?(\"my_feature\")\ntrue\n```\n\nYou can also enable flags specifically for some arbitrary resource:\n\n```elixir\niex> Toggle.disable!(\"my_feature\")\n:ok\niex> Toggle.enable!(\"my_feature\", user_id: 123)\n:ok\niex> Toggle.enabled?(\"my_feature\")\nfalse\niex> Toggle.enabled?(\"my_feature\", user_id: 123)\ntrue\n```\n\nResources are key-value pairs that can be used to enable or disable a flag for a specific entity. The expected data\ntype for both the key and value is an atom, string, or integer.\n\nToday, toggle only supports boolean flags, but we plan to add support for more flag types in the future.\n\nWhether or not a flag is enabled is determined by the following rules:\n\n- If a flag is enabled for a resource, that resource's value takes precedence over the global value.\n- If a flag is disabled for a resource, that resource's value takes precedence over the global value.\n- Otherwise, the global value is used.\n\n> #### Info {: .info}\n>\n> One edge case is that `Toggle.disabled?/1` and `Toggle.disabled?/2` are implemented as inverses of `Toggle.enabled?/1` and\n> `Toggle.enabled?/2` which means that if a flag does not exist, it is considered disabled.","ref":"Toggle.html#module-usage","title":"Usage - Toggle","type":"module"},{"doc":"Querying flags on every request can be expensive, so `Toggle` provides a caching layer to speed up flag lookups.\n\nWhenever a flag is created, updated, or deleted, we update a cache with the latest flag data using `Cachex` under the\n`:toggle_cache` namespace.\n\nWhenever the cache is mutated, `Toggle.Cache` will asynchronously publish the changes to all other connected nodes\nusing Erlang's `:erpc` module. In the future, we plan to add support for other pubsub strategies.\n\nUsing `Toggle.enabled?/1`, `Toggle.enabled?/2`, `Toggle.disabled?/1`, or `Toggle.disabled?/2` will automatically use\nthe cache if it is available.\n\nThe cache has a default ttl of one minute.","ref":"Toggle.html#module-caching","title":"Caching - Toggle","type":"module"},{"doc":"`Toggle` aims to be as simple as possible, and as such, it does not require any configuration.\n\nThe only possible configuration at the time of writing is:\n\n- `:flag_table_name` - The name of the database table used to store flags. Defaults to `\"toggle_flags\"`.\n- `:cache_ttl` - The time-to-live for cached flags. Defaults to 1 minute.\n\nSee `Toggle.Comptime` for more information.","ref":"Toggle.html#module-configuration","title":"Configuration - Toggle","type":"module"},{"doc":"The core API for `Toggle` is provided by the `Toggle` module. You can use the `Toggle` module to enable and disable flags,\nand check if a flag is enabled or disabled.\n\nFor more complex querying, please see the `Toggle.Flags` module, the `Toggle.Flags.Flag` schema, and the libraries\nthis application is built on: `EctoModel` and `EctoHooks`.\n\nThe `Toggle.Flags.Flag` schema implements the `EctoModel.Queryable` behaviour, which lends itself well to fluent-api\nstyle querying.\n\nFor example, you are able to query flags using the `Toggle.Flags.Flag.query/2` function:\n\n```elixir\niex> MyApp.Repo.one(Toggle.Flags.Flag.query(name: \"my_flag\", disabled: true))\n%Toggle.Flags.Flag{name: \"my_flag\", enabled: false}\n```\n\nAdditionally, please feel free to query the `Toggle.Flags.Flag` schema directly.","ref":"Toggle.html#module-further-reading","title":"Further Reading - Toggle","type":"module"},{"doc":"- Add support for more flag types such as `:percentage` and `:datetime`.\n- Add support for deprecating flags and emitting deprecation warnings after a certain date.\n- Add support for hooks that can be run before or after a flag is enabled or disabled.\n- Pluggable pub/sub strategies.\n- Add a `Phoenix.LiveView` interface for managing flags in real-time.\n    - Including metrics and analytics for flag usage.","ref":"Toggle.html#module-future-work","title":"Future Work - Toggle","type":"module"},{"doc":"","ref":"Toggle.html#disable!/1","title":"Toggle.disable!/1","type":"function"},{"doc":"","ref":"Toggle.html#disable!/2","title":"Toggle.disable!/2","type":"function"},{"doc":"","ref":"Toggle.html#disabled?/1","title":"Toggle.disabled?/1","type":"function"},{"doc":"","ref":"Toggle.html#disabled?/2","title":"Toggle.disabled?/2","type":"function"},{"doc":"","ref":"Toggle.html#enable!/1","title":"Toggle.enable!/1","type":"function"},{"doc":"","ref":"Toggle.html#enable!/2","title":"Toggle.enable!/2","type":"function"},{"doc":"","ref":"Toggle.html#enabled?/1","title":"Toggle.enabled?/1","type":"function"},{"doc":"","ref":"Toggle.html#enabled?/2","title":"Toggle.enabled?/2","type":"function"},{"doc":"Module responsible for caching values in memory.","ref":"Toggle.Cache.html","title":"Toggle.Cache","type":"module"},{"doc":"Module for handling compile-time parameters and configuration.","ref":"Toggle.Comptime.html","title":"Toggle.Comptime","type":"module"},{"doc":"Returns the ttl for cached flags. Defaults to 1 minute.","ref":"Toggle.Comptime.html#cache_ttl/0","title":"Toggle.Comptime.cache_ttl/0","type":"function"},{"doc":"The repo used to store flags. Defaults to Toggle.Repo.","ref":"Toggle.Comptime.html#repo/0","title":"Toggle.Comptime.repo/0","type":"function"},{"doc":"Returns the name of the database table used to store flags. Defaults to \"toggle_flags\".","ref":"Toggle.Comptime.html#table_name/1","title":"Toggle.Comptime.table_name/1","type":"function"},{"doc":"Provides a set of functions for managing feature flags.\n\nA feature flag in `Toggle` is a named boolean value that can be enabled or disabled on two levels:\n\n- Globally: The flag is either enabled or disabled for all resources.\n- Individually: The flag can be enabled or disabled for a specific resource.\n\nA resource is a key-value pair that can be used to enable or disable a flag for a specific entity,\nfor example: `org_id: 123` or `user_id: 456`.\n\nWhen a flag is enabled for a resource, that resource's value takes precedence over the global value,\nfor example:\n\n```elixir\niex> Flags.create_flag(%{name: \"my_flag\", enabled: true})\niex> Flags.enabled?(\"my_flag\")\ntrue\niex> Flags.enabled?(\"my_flag\", org_id: 123)\ntrue\niex> Flags.disable!(\"my_flag\", org_id: 123)\niex> Flags.enabled?(\"my_flag\")\ntrue\niex> Flags.enabled?(\"my_flag\", org_id: 353)\ntrue\niex> Flags.enabled?(\"my_flag\", org_id: 123)\nfalse\n```","ref":"Toggle.Flags.html","title":"Toggle.Flags","type":"module"},{"doc":"Creates a new flag.","ref":"Toggle.Flags.html#create_flag/1","title":"Toggle.Flags.create_flag/1","type":"function"},{"doc":"Deletes a flag.","ref":"Toggle.Flags.html#delete_flag/1","title":"Toggle.Flags.delete_flag/1","type":"function"},{"doc":"Globally disables the given flag. Will create the given flag if it does not exist.","ref":"Toggle.Flags.html#disable!/1","title":"Toggle.Flags.disable!/1","type":"function"},{"doc":"Disable the given flag for the given resource. Will create the given flag if it does not exist.","ref":"Toggle.Flags.html#disable!/2","title":"Toggle.Flags.disable!/2","type":"function"},{"doc":"Is the given flag disabled?","ref":"Toggle.Flags.html#disabled?/1","title":"Toggle.Flags.disabled?/1","type":"function"},{"doc":"Returns if the given flag is disabled for the given entity.","ref":"Toggle.Flags.html#disabled?/2","title":"Toggle.Flags.disabled?/2","type":"function"},{"doc":"Globally enables the given flag. Will create the given flag if it does not exist.","ref":"Toggle.Flags.html#enable!/1","title":"Toggle.Flags.enable!/1","type":"function"},{"doc":"Enable the given flag for the given resource. Will create the given flag if it does not exist.","ref":"Toggle.Flags.html#enable!/2","title":"Toggle.Flags.enable!/2","type":"function"},{"doc":"Is the given flag enabled?","ref":"Toggle.Flags.html#enabled?/1","title":"Toggle.Flags.enabled?/1","type":"function"},{"doc":"Returns if the given flag is enabled for the given resource.","ref":"Toggle.Flags.html#enabled?/2","title":"Toggle.Flags.enabled?/2","type":"function"},{"doc":"","ref":"Toggle.Flags.html#get_flag/1","title":"Toggle.Flags.get_flag/1","type":"function"},{"doc":"Get a flag by the given filters.","ref":"Toggle.Flags.html#get_flag/2","title":"Toggle.Flags.get_flag/2","type":"function"},{"doc":"Get all flags by the given filters.","ref":"Toggle.Flags.html#list_flags/1","title":"Toggle.Flags.list_flags/1","type":"function"},{"doc":"Updates a flag.","ref":"Toggle.Flags.html#update_flag/2","title":"Toggle.Flags.update_flag/2","type":"function"},{"doc":"","ref":"Toggle.Flags.html#t:resource/0","title":"Toggle.Flags.resource/0","type":"type"},{"doc":"","ref":"Toggle.Flags.html#t:resource_key/0","title":"Toggle.Flags.resource_key/0","type":"type"},{"doc":"","ref":"Toggle.Flags.html#t:resource_value/0","title":"Toggle.Flags.resource_value/0","type":"type"},{"doc":"Schema for a feature flag as defined by `Toggle`.\n\nProvides utility functions for easily creating data. Note that reads to this schema may\nbe cached depending on the given adapter.","ref":"Toggle.Flags.Flag.html","title":"Toggle.Flags.Flag","type":"module"},{"doc":"","ref":"Toggle.Flags.Flag.html#after_delete/2","title":"Toggle.Flags.Flag.after_delete/2","type":"function"},{"doc":"","ref":"Toggle.Flags.Flag.html#after_get/2","title":"Toggle.Flags.Flag.after_get/2","type":"function"},{"doc":"","ref":"Toggle.Flags.Flag.html#after_insert/2","title":"Toggle.Flags.Flag.after_insert/2","type":"function"},{"doc":"","ref":"Toggle.Flags.Flag.html#after_update/2","title":"Toggle.Flags.Flag.after_update/2","type":"function"},{"doc":"","ref":"Toggle.Flags.Flag.html#changeset/2","title":"Toggle.Flags.Flag.changeset/2","type":"function"},{"doc":"","ref":"Toggle.Flags.Flag.html#t:t/0","title":"Toggle.Flags.Flag.t/0","type":"type"},{"doc":"Migrations for bootstrapping Toggle on Postgres","ref":"Toggle.Migrations.Postgres.html","title":"Toggle.Migrations.Postgres","type":"module"},{"doc":"","ref":"Toggle.Migrations.Postgres.html#down/1","title":"Toggle.Migrations.Postgres.down/1","type":"function"},{"doc":"","ref":"Toggle.Migrations.Postgres.html#up/1","title":"Toggle.Migrations.Postgres.up/1","type":"function"},{"doc":"Migrations for bootstrapping Toggle on SQLite","ref":"Toggle.Migrations.SQLite.html","title":"Toggle.Migrations.SQLite","type":"module"},{"doc":"","ref":"Toggle.Migrations.SQLite.html#down/1","title":"Toggle.Migrations.SQLite.down/1","type":"function"},{"doc":"","ref":"Toggle.Migrations.SQLite.html#up/1","title":"Toggle.Migrations.SQLite.up/1","type":"function"},{"doc":"The entrypoint for defining your web interface, such\nas controllers, components, channels, and so on.\n\nThis can be used in your application as:\n\n    use ToggleWeb, :controller\n    use ToggleWeb, :html\n\nThe definitions below will be executed for every controller,\ncomponent, etc, so keep them short and clean, focused\non imports, uses and aliases.\n\nDo NOT define functions inside the quoted expressions\nbelow. Instead, define additional modules and import\nthose modules here.","ref":"ToggleWeb.html","title":"ToggleWeb","type":"module"},{"doc":"When used, dispatch to the appropriate controller/live_view/etc.","ref":"ToggleWeb.html#__using__/1","title":"ToggleWeb.__using__/1","type":"macro"},{"doc":"","ref":"ToggleWeb.html#channel/0","title":"ToggleWeb.channel/0","type":"function"},{"doc":"","ref":"ToggleWeb.html#controller/0","title":"ToggleWeb.controller/0","type":"function"},{"doc":"","ref":"ToggleWeb.html#html/0","title":"ToggleWeb.html/0","type":"function"},{"doc":"","ref":"ToggleWeb.html#live_component/0","title":"ToggleWeb.live_component/0","type":"function"},{"doc":"","ref":"ToggleWeb.html#live_view/0","title":"ToggleWeb.live_view/0","type":"function"},{"doc":"","ref":"ToggleWeb.html#router/0","title":"ToggleWeb.router/0","type":"function"},{"doc":"","ref":"ToggleWeb.html#static_paths/0","title":"ToggleWeb.static_paths/0","type":"function"},{"doc":"","ref":"ToggleWeb.html#verified_routes/0","title":"ToggleWeb.verified_routes/0","type":"function"},{"doc":"Provides core UI components.\n\nAt first glance, this module may seem daunting, but its goal is to provide\ncore building blocks for your application, such as modals, tables, and\nforms. The components consist mostly of markup and are well-documented\nwith doc strings and declarative assigns. You may customize and style\nthem in any way you want, based on your application growth and needs.\n\nThe default components use Tailwind CSS, a utility-first CSS framework.\nSee the [Tailwind CSS documentation](https://tailwindcss.com) to learn\nhow to customize them or feel free to swap in another framework altogether.\n\nIcons are provided by [heroicons](https://heroicons.com). See `icon/1` for usage.","ref":"ToggleWeb.CoreComponents.html","title":"ToggleWeb.CoreComponents","type":"module"},{"doc":"Renders a back navigation link.","ref":"ToggleWeb.CoreComponents.html#back/1","title":"ToggleWeb.CoreComponents.back/1","type":"function"},{"doc":"<.back navigate={~p\"/posts\"}>Back to posts</.back>","ref":"ToggleWeb.CoreComponents.html#back/1-examples","title":"Examples - ToggleWeb.CoreComponents.back/1","type":"function"},{"doc":"* `navigate` (`:any`) (required)","ref":"ToggleWeb.CoreComponents.html#back/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.back/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"ToggleWeb.CoreComponents.html#back/1-slots","title":"Slots - ToggleWeb.CoreComponents.back/1","type":"function"},{"doc":"Renders a button.","ref":"ToggleWeb.CoreComponents.html#button/1","title":"ToggleWeb.CoreComponents.button/1","type":"function"},{"doc":"<.button>Send!</.button>\n    <.button phx-click=\"go\" class=\"ml-2\">Send!</.button>","ref":"ToggleWeb.CoreComponents.html#button/1-examples","title":"Examples - ToggleWeb.CoreComponents.button/1","type":"function"},{"doc":"* `type` (`:string`) - Defaults to `nil`.\n* `class` (`:string`) - Defaults to `nil`.\n* Global attributes are accepted. Supports all globals plus: `[\"disabled\", \"form\", \"name\", \"value\"]`.","ref":"ToggleWeb.CoreComponents.html#button/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.button/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"ToggleWeb.CoreComponents.html#button/1-slots","title":"Slots - ToggleWeb.CoreComponents.button/1","type":"function"},{"doc":"Generates a generic error message.","ref":"ToggleWeb.CoreComponents.html#error/1","title":"ToggleWeb.CoreComponents.error/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"ToggleWeb.CoreComponents.html#error/1-slots","title":"Slots - ToggleWeb.CoreComponents.error/1","type":"function"},{"doc":"Renders flash notices.","ref":"ToggleWeb.CoreComponents.html#flash/1","title":"ToggleWeb.CoreComponents.flash/1","type":"function"},{"doc":"<.flash kind={:info} flash={@flash} />\n    <.flash kind={:info} phx-mounted={show(\"#flash\")}>Welcome Back!</.flash>","ref":"ToggleWeb.CoreComponents.html#flash/1-examples","title":"Examples - ToggleWeb.CoreComponents.flash/1","type":"function"},{"doc":"* `id` (`:string`) - the optional id of flash container.\n* `flash` (`:map`) - the map of flash messages to display. Defaults to `%{}`.\n* `title` (`:string`) - Defaults to `nil`.\n* `kind` (`:atom`) - used for styling and flash lookup.Must be one of `:info`, or `:error`.\n* Global attributes are accepted. the arbitrary HTML attributes to add to the flash container.","ref":"ToggleWeb.CoreComponents.html#flash/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.flash/1","type":"function"},{"doc":"* `inner_block` - the optional inner block that renders the flash message.","ref":"ToggleWeb.CoreComponents.html#flash/1-slots","title":"Slots - ToggleWeb.CoreComponents.flash/1","type":"function"},{"doc":"Shows the flash group with standard titles and content.","ref":"ToggleWeb.CoreComponents.html#flash_group/1","title":"ToggleWeb.CoreComponents.flash_group/1","type":"function"},{"doc":"<.flash_group flash={@flash} />","ref":"ToggleWeb.CoreComponents.html#flash_group/1-examples","title":"Examples - ToggleWeb.CoreComponents.flash_group/1","type":"function"},{"doc":"* `flash` (`:map`) (required) - the map of flash messages.\n* `id` (`:string`) - the optional id of flash container. Defaults to `\"flash-group\"`.","ref":"ToggleWeb.CoreComponents.html#flash_group/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.flash_group/1","type":"function"},{"doc":"Renders a header with title.","ref":"ToggleWeb.CoreComponents.html#header/1","title":"ToggleWeb.CoreComponents.header/1","type":"function"},{"doc":"* `class` (`:string`) - Defaults to `nil`.","ref":"ToggleWeb.CoreComponents.html#header/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.header/1","type":"function"},{"doc":"* `inner_block` (required)\n* `subtitle`\n* `actions`","ref":"ToggleWeb.CoreComponents.html#header/1-slots","title":"Slots - ToggleWeb.CoreComponents.header/1","type":"function"},{"doc":"","ref":"ToggleWeb.CoreComponents.html#hide/2","title":"ToggleWeb.CoreComponents.hide/2","type":"function"},{"doc":"","ref":"ToggleWeb.CoreComponents.html#hide_modal/2","title":"ToggleWeb.CoreComponents.hide_modal/2","type":"function"},{"doc":"Renders a [Heroicon](https://heroicons.com).\n\nHeroicons come in three styles – outline, solid, and mini.\nBy default, the outline style is used, but solid and mini may\nbe applied by using the `-solid` and `-mini` suffix.\n\nYou can customize the size and colors of the icons by setting\nwidth, height, and background color classes.\n\nIcons are extracted from the `deps/heroicons` directory and bundled within\nyour compiled app.css by the plugin in your `assets/tailwind.config.js`.","ref":"ToggleWeb.CoreComponents.html#icon/1","title":"ToggleWeb.CoreComponents.icon/1","type":"function"},{"doc":"<.icon name=\"hero-x-mark-solid\" />\n    <.icon name=\"hero-arrow-path\" class=\"ml-1 w-3 h-3 animate-spin\" />","ref":"ToggleWeb.CoreComponents.html#icon/1-examples","title":"Examples - ToggleWeb.CoreComponents.icon/1","type":"function"},{"doc":"* `name` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.","ref":"ToggleWeb.CoreComponents.html#icon/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.icon/1","type":"function"},{"doc":"Renders an input with label and error messages.\n\nA `Phoenix.HTML.FormField` may be passed as argument,\nwhich is used to retrieve the input name, id, and values.\nOtherwise all attributes may be passed explicitly.","ref":"ToggleWeb.CoreComponents.html#input/1","title":"ToggleWeb.CoreComponents.input/1","type":"function"},{"doc":"This function accepts all HTML input types, considering that:\n\n  * You may also set `type=\"select\"` to render a ` ` tag\n\n  * `type=\"checkbox\"` is used exclusively to render boolean values\n\n  * For live file uploads, see `Phoenix.Component.live_file_input/1`\n\nSee https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input\nfor more information. Unsupported types, such as hidden and radio,\nare best written directly in your templates.","ref":"ToggleWeb.CoreComponents.html#input/1-types","title":"Types - ToggleWeb.CoreComponents.input/1","type":"function"},{"doc":"<.input field={@form[:email]} type=\"email\" />\n    <.input name=\"my-input\" errors={[\"oh no!\"]} />","ref":"ToggleWeb.CoreComponents.html#input/1-examples","title":"Examples - ToggleWeb.CoreComponents.input/1","type":"function"},{"doc":"* `id` (`:any`) - Defaults to `nil`.\n* `name` (`:any`)\n* `label` (`:string`) - Defaults to `nil`.\n* `value` (`:any`)\n* `type` (`:string`) - Defaults to `\"text\"`.\n* `field` (`Phoenix.HTML.FormField`) - a form field struct retrieved from the form, for example: @form[:email].\n* `errors` (`:list`) - Defaults to `[]`.\n* `checked` (`:boolean`) - the checked flag for checkbox inputs.\n* `prompt` (`:string`) - the prompt for select inputs. Defaults to `nil`.\n* `options` (`:list`) - the options to pass to Phoenix.HTML.Form.options_for_select/2.\n* `multiple` (`:boolean`) - the multiple flag for select inputs. Defaults to `false`.\n* Global attributes are accepted. Supports all globals plus: `[\"accept\", \"autocomplete\", \"capture\", \"cols\", \"disabled\", \"form\", \"list\", \"max\", \"maxlength\", \"min\", \"minlength\", \"multiple\", \"pattern\", \"placeholder\", \"readonly\", \"required\", \"rows\", \"size\", \"step\"]`.","ref":"ToggleWeb.CoreComponents.html#input/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.input/1","type":"function"},{"doc":"Renders a label.","ref":"ToggleWeb.CoreComponents.html#label/1","title":"ToggleWeb.CoreComponents.label/1","type":"function"},{"doc":"* `for` (`:string`) - Defaults to `nil`.","ref":"ToggleWeb.CoreComponents.html#label/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.label/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"ToggleWeb.CoreComponents.html#label/1-slots","title":"Slots - ToggleWeb.CoreComponents.label/1","type":"function"},{"doc":"Renders a data list.","ref":"ToggleWeb.CoreComponents.html#list/1","title":"ToggleWeb.CoreComponents.list/1","type":"function"},{"doc":"<.list>\n      <:item title=\"Title\"><%= @post.title %></:item>\n      <:item title=\"Views\"><%= @post.views %></:item>\n    </.list>","ref":"ToggleWeb.CoreComponents.html#list/1-examples","title":"Examples - ToggleWeb.CoreComponents.list/1","type":"function"},{"doc":"* `item` (required) - Accepts attributes:\n\n  * `title` (`:string`) (required)","ref":"ToggleWeb.CoreComponents.html#list/1-slots","title":"Slots - ToggleWeb.CoreComponents.list/1","type":"function"},{"doc":"Renders a modal.","ref":"ToggleWeb.CoreComponents.html#modal/1","title":"ToggleWeb.CoreComponents.modal/1","type":"function"},{"doc":"<.modal id=\"confirm-modal\">\n      This is a modal.\n    </.modal>\n\nJS commands may be passed to the `:on_cancel` to configure\nthe closing/cancel event, for example:\n\n    <.modal id=\"confirm\" on_cancel={JS.navigate(~p\"/posts\")}>\n      This is another modal.\n    </.modal>","ref":"ToggleWeb.CoreComponents.html#modal/1-examples","title":"Examples - ToggleWeb.CoreComponents.modal/1","type":"function"},{"doc":"* `id` (`:string`) (required)\n* `show` (`:boolean`) - Defaults to `false`.\n* `on_cancel` (`Phoenix.LiveView.JS`) - Defaults to `%Phoenix.LiveView.JS{ops: []}`.","ref":"ToggleWeb.CoreComponents.html#modal/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.modal/1","type":"function"},{"doc":"* `inner_block` (required)","ref":"ToggleWeb.CoreComponents.html#modal/1-slots","title":"Slots - ToggleWeb.CoreComponents.modal/1","type":"function"},{"doc":"","ref":"ToggleWeb.CoreComponents.html#show/2","title":"ToggleWeb.CoreComponents.show/2","type":"function"},{"doc":"","ref":"ToggleWeb.CoreComponents.html#show_modal/2","title":"ToggleWeb.CoreComponents.show_modal/2","type":"function"},{"doc":"Renders a simple form.","ref":"ToggleWeb.CoreComponents.html#simple_form/1","title":"ToggleWeb.CoreComponents.simple_form/1","type":"function"},{"doc":"<.simple_form for={@form} phx-change=\"validate\" phx-submit=\"save\">\n      <.input field={@form[:email]} label=\"Email\"/>\n      <.input field={@form[:username]} label=\"Username\" />\n      <:actions>\n        <.button>Save</.button>\n      </:actions>\n    </.simple_form>","ref":"ToggleWeb.CoreComponents.html#simple_form/1-examples","title":"Examples - ToggleWeb.CoreComponents.simple_form/1","type":"function"},{"doc":"* `for` (`:any`) (required) - the data structure for the form.\n* `as` (`:any`) - the server side parameter to collect all input under. Defaults to `nil`.\n* Global attributes are accepted. the arbitrary HTML attributes to apply to the form tag. Supports all globals plus: `[\"autocomplete\", \"name\", \"rel\", \"action\", \"enctype\", \"method\", \"novalidate\", \"target\", \"multipart\"]`.","ref":"ToggleWeb.CoreComponents.html#simple_form/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.simple_form/1","type":"function"},{"doc":"* `inner_block` (required)\n* `actions` - the slot for form actions, such as a submit button.","ref":"ToggleWeb.CoreComponents.html#simple_form/1-slots","title":"Slots - ToggleWeb.CoreComponents.simple_form/1","type":"function"},{"doc":"Renders a table with generic styling.","ref":"ToggleWeb.CoreComponents.html#table/1","title":"ToggleWeb.CoreComponents.table/1","type":"function"},{"doc":"<.table id=\"users\" rows={@users}>\n      <:col :let={user} label=\"id\"><%= user.id %></:col>\n      <:col :let={user} label=\"username\"><%= user.username %></:col>\n    </.table>","ref":"ToggleWeb.CoreComponents.html#table/1-examples","title":"Examples - ToggleWeb.CoreComponents.table/1","type":"function"},{"doc":"* `id` (`:string`) (required)\n* `rows` (`:list`) (required)\n* `row_id` (`:any`) - the function for generating the row id. Defaults to `nil`.\n* `row_click` (`:any`) - the function for handling phx-click on each row. Defaults to `nil`.\n* `row_item` (`:any`) - the function for mapping each row before calling the :col and :action slots. Defaults to `&Function.identity/1`.","ref":"ToggleWeb.CoreComponents.html#table/1-attributes","title":"Attributes - ToggleWeb.CoreComponents.table/1","type":"function"},{"doc":"* `col` (required) - Accepts attributes:\n\n  * `label` (`:string`)\n* `action` - the slot for showing user actions in the last table column.","ref":"ToggleWeb.CoreComponents.html#table/1-slots","title":"Slots - ToggleWeb.CoreComponents.table/1","type":"function"},{"doc":"Translates an error message using gettext.","ref":"ToggleWeb.CoreComponents.html#translate_error/1","title":"ToggleWeb.CoreComponents.translate_error/1","type":"function"},{"doc":"Translates the errors for a field from a keyword list of errors.","ref":"ToggleWeb.CoreComponents.html#translate_errors/2","title":"ToggleWeb.CoreComponents.translate_errors/2","type":"function"},{"doc":"","ref":"ToggleWeb.Endpoint.html","title":"ToggleWeb.Endpoint","type":"module"},{"doc":"","ref":"ToggleWeb.Endpoint.html#broadcast/3","title":"ToggleWeb.Endpoint.broadcast/3","type":"function"},{"doc":"","ref":"ToggleWeb.Endpoint.html#broadcast!/3","title":"ToggleWeb.Endpoint.broadcast!/3","type":"function"},{"doc":"","ref":"ToggleWeb.Endpoint.html#broadcast_from/4","title":"ToggleWeb.Endpoint.broadcast_from/4","type":"function"},{"doc":"","ref":"ToggleWeb.Endpoint.html#broadcast_from!/4","title":"ToggleWeb.Endpoint.broadcast_from!/4","type":"function"},{"doc":"","ref":"ToggleWeb.Endpoint.html#call/2","title":"ToggleWeb.Endpoint.call/2","type":"function"},{"doc":"Returns the child specification to start the endpoint\nunder a supervision tree.","ref":"ToggleWeb.Endpoint.html#child_spec/1","title":"ToggleWeb.Endpoint.child_spec/1","type":"function"},{"doc":"Returns the endpoint configuration for `key`\n\nReturns `default` if the key does not exist.","ref":"ToggleWeb.Endpoint.html#config/2","title":"ToggleWeb.Endpoint.config/2","type":"function"},{"doc":"Reloads the configuration given the application environment changes.","ref":"ToggleWeb.Endpoint.html#config_change/2","title":"ToggleWeb.Endpoint.config_change/2","type":"function"},{"doc":"Returns the host for the given endpoint.","ref":"ToggleWeb.Endpoint.html#host/0","title":"ToggleWeb.Endpoint.host/0","type":"function"},{"doc":"","ref":"ToggleWeb.Endpoint.html#init/1","title":"ToggleWeb.Endpoint.init/1","type":"function"},{"doc":"","ref":"ToggleWeb.Endpoint.html#local_broadcast/3","title":"ToggleWeb.Endpoint.local_broadcast/3","type":"function"},{"doc":"","ref":"ToggleWeb.Endpoint.html#local_broadcast_from/4","title":"ToggleWeb.Endpoint.local_broadcast_from/4","type":"function"},{"doc":"Generates the path information when routing to this endpoint.","ref":"ToggleWeb.Endpoint.html#path/1","title":"ToggleWeb.Endpoint.path/1","type":"function"},{"doc":"Generates the script name.","ref":"ToggleWeb.Endpoint.html#script_name/0","title":"ToggleWeb.Endpoint.script_name/0","type":"function"},{"doc":"Returns the address and port that the server is running on","ref":"ToggleWeb.Endpoint.html#server_info/1","title":"ToggleWeb.Endpoint.server_info/1","type":"function"},{"doc":"Starts the endpoint supervision tree.\n\nAll other options are merged into the endpoint configuration.","ref":"ToggleWeb.Endpoint.html#start_link/1","title":"ToggleWeb.Endpoint.start_link/1","type":"function"},{"doc":"Generates a base64-encoded cryptographic hash (sha512) to a static file\nin `priv/static`. Meant to be used for Subresource Integrity with CDNs.","ref":"ToggleWeb.Endpoint.html#static_integrity/1","title":"ToggleWeb.Endpoint.static_integrity/1","type":"function"},{"doc":"Returns a two item tuple with the first item being the `static_path`\nand the second item being the `static_integrity`.","ref":"ToggleWeb.Endpoint.html#static_lookup/1","title":"ToggleWeb.Endpoint.static_lookup/1","type":"function"},{"doc":"Generates a route to a static file in `priv/static`.","ref":"ToggleWeb.Endpoint.html#static_path/1","title":"ToggleWeb.Endpoint.static_path/1","type":"function"},{"doc":"Generates the static URL without any path information.\n\nIt uses the configuration under `:static_url` to generate\nsuch. It falls back to `:url` if `:static_url` is not set.","ref":"ToggleWeb.Endpoint.html#static_url/0","title":"ToggleWeb.Endpoint.static_url/0","type":"function"},{"doc":"Generates the endpoint base URL but as a `URI` struct.\n\nIt uses the configuration under `:url` to generate such.\nUseful for manipulating the URL data and passing it to\nURL helpers.","ref":"ToggleWeb.Endpoint.html#struct_url/0","title":"ToggleWeb.Endpoint.struct_url/0","type":"function"},{"doc":"","ref":"ToggleWeb.Endpoint.html#subscribe/2","title":"ToggleWeb.Endpoint.subscribe/2","type":"function"},{"doc":"","ref":"ToggleWeb.Endpoint.html#unsubscribe/1","title":"ToggleWeb.Endpoint.unsubscribe/1","type":"function"},{"doc":"Generates the endpoint base URL without any path information.\n\nIt uses the configuration under `:url` to generate such.","ref":"ToggleWeb.Endpoint.html#url/0","title":"ToggleWeb.Endpoint.url/0","type":"function"},{"doc":"This module is invoked by your endpoint in case of errors on HTML requests.\n\nSee config/config.exs.","ref":"ToggleWeb.ErrorHTML.html","title":"ToggleWeb.ErrorHTML","type":"module"},{"doc":"","ref":"ToggleWeb.ErrorHTML.html#render/2","title":"ToggleWeb.ErrorHTML.render/2","type":"function"},{"doc":"This module is invoked by your endpoint in case of errors on JSON requests.\n\nSee config/config.exs.","ref":"ToggleWeb.ErrorJSON.html","title":"ToggleWeb.ErrorJSON","type":"module"},{"doc":"","ref":"ToggleWeb.ErrorJSON.html#render/2","title":"ToggleWeb.ErrorJSON.render/2","type":"function"},{"doc":"This module holds different layouts used by your application.\n\nSee the `layouts` directory for all templates available.\nThe \"root\" layout is a skeleton rendered as part of the\napplication router. The \"app\" layout is set as the default\nlayout on both `use ToggleWeb, :controller` and\n`use ToggleWeb, :live_view`.","ref":"ToggleWeb.Layouts.html","title":"ToggleWeb.Layouts","type":"module"},{"doc":"","ref":"ToggleWeb.Layouts.html#app/1","title":"ToggleWeb.Layouts.app/1","type":"function"},{"doc":"","ref":"ToggleWeb.Layouts.html#root/1","title":"ToggleWeb.Layouts.root/1","type":"function"},{"doc":"","ref":"ToggleWeb.PageController.html","title":"ToggleWeb.PageController","type":"module"},{"doc":"","ref":"ToggleWeb.PageController.html#home/2","title":"ToggleWeb.PageController.home/2","type":"function"},{"doc":"This module contains pages rendered by PageController.\n\nSee the `page_html` directory for all templates available.","ref":"ToggleWeb.PageHTML.html","title":"ToggleWeb.PageHTML","type":"module"},{"doc":"","ref":"ToggleWeb.PageHTML.html#home/1","title":"ToggleWeb.PageHTML.home/1","type":"function"},{"doc":"","ref":"ToggleWeb.Router.html","title":"ToggleWeb.Router","type":"module"},{"doc":"","ref":"ToggleWeb.Router.html#api/2","title":"ToggleWeb.Router.api/2","type":"function"},{"doc":"","ref":"ToggleWeb.Router.html#browser/2","title":"ToggleWeb.Router.browser/2","type":"function"},{"doc":"Callback invoked by Plug on every request.","ref":"ToggleWeb.Router.html#call/2","title":"ToggleWeb.Router.call/2","type":"function"},{"doc":"Callback required by Plug that initializes the router\nfor serving web requests.","ref":"ToggleWeb.Router.html#init/1","title":"ToggleWeb.Router.init/1","type":"function"}],"producer":{"name":"ex_doc","version":"0.35.1"},"proglang":"elixir"}